@@ -88,7 +88,7 @@ static struct {
 	unsigned char rxbuf[1024];
 	/* HDLC receiver */
         struct {
-                unsigned int bitbuf, bitstream, numbits, state;
+                unsigned int bitbuf, bitstream, numbits, state, passall;
                 unsigned char *bufptr;
                 int bufcnt;
                 unsigned char buf[RXBUFFER_SIZE];
@@ -108,7 +108,7 @@ static struct {
 	0, &modchain_x, &demodchain_x, NULL, NULL, 0,
 	0, { 0, 0, 0, 0, }, 
 	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, { 0, },
-	{ 0, 0, 0, 0, },
+	{ 0, 0, 0, 0, 0, },
         0,
         NULL, NULL, 0,
 	PTHREAD_COND_INITIALIZER, PTHREAD_MUTEX_INITIALIZER,
@@ -191,7 +191,7 @@ static void do_rxpacket(void)
         if (diagstate.hrx.bufcnt < 3) 
                 return;
 #if 1
-        if (!check_crc_ccitt(diagstate.hrx.buf, diagstate.hrx.bufcnt)) 
+        if (!diagstate.hrx.passall && !check_crc_ccitt(diagstate.hrx.buf, diagstate.hrx.bufcnt)) 
                 return;
 #endif
         {
@@ -213,7 +213,7 @@ static void do_rxpacket(void)
                 goto flgabrt##j;                                              \
         if ((bitstream & (0x1f8 << j)) == (0xf8 << j))   /* stuffed bit */    \
                 goto stuff##j;                                                \
-  enditer##j:                                                                 \
+  enditer##j:;                                                                \
 })
 
 #define DECODEITERB(j)                                                                 \
@@ -804,6 +804,13 @@ void on_diagp3dmodem_activate(GtkMenuItem *menuitem, gpointer user_data)
 	gtk_widget_show(p3dwindow);
 }
 
+void on_diagpassall_activate(GtkMenuItem *menuitem, gpointer user_data)
+{
+	GtkCheckMenuItem *citem = GTK_CHECK_MENU_ITEM(menuitem);
+	printf("passall: %u\n", citem->active);
+	diagstate.hrx.passall = citem->active;
+}
+
 /* ---------------------------------------------------------------------- */
 
 void on_ptt_toggled(GtkToggleButton *togglebutton, gpointer user_data)
