@@ -588,7 +588,7 @@ u_int16_t audiocurtime(struct modemchannel *chan)
 
 int pktget(struct modemchannel *chan, unsigned char *data, unsigned int len)
 {
-	unsigned int j;
+	unsigned int j, n = len;
 
 	pthread_mutex_lock(&state.txmutex);
 	if (!state.active) {
@@ -601,41 +601,42 @@ int pktget(struct modemchannel *chan, unsigned char *data, unsigned int len)
 	if (chan->htx.rd == chan->htx.wr) {
 		if (!chan->calib) {
 			pthread_mutex_unlock(&state.txmutex);
-			return -1;
+			return 0;
 		}
 		/* check first if anyone else has a real packet to send */
 		for (j = 0; j < state.nrchannels; j++)
 			if (state.chan[j].htx.rd != state.chan[j].htx.wr) {
 				pthread_mutex_unlock(&state.txmutex);
-				return -1;
+				return 0;
 			}
 		/* fill calib */
-		if (chan->calib < len)
+		if (chan->calib < n) {
+			n = chan->calib;
 			chan->calib = 0;
-		else
-			chan->calib -= len;
-		memset(data, 0, len);
+		} else
+			chan->calib -= n;
+		memset(data, 0, n);
 		pthread_mutex_unlock(&state.txmutex);
-		return -0;
+		return n;
 	}
-	while (len > 0) {
+	while (n > 0) {
 		if (chan->htx.wr >= chan->htx.rd)
 			j = chan->htx.wr - chan->htx.rd;
 		else
 			j = TXBUFFER_SIZE - chan->htx.rd;
-		if (j > len)
-			j = len;
+		if (j > n)
+			j = n;
 		if (!j)
 			break;
 		memcpy(data, &chan->htx.buf[chan->htx.rd], j);
 		data += j;
-		len -= j;
+		n -= j;
 		chan->htx.rd = (chan->htx.rd + j) % TXBUFFER_SIZE;
 	}
-	if (len > 0)
-		memset(data, 0, len);
+	if (n > 0)
+		memset(data, 0, n);
 	pthread_mutex_unlock(&state.txmutex);
-	return 0;
+	return (len - n);
 }
 
 void pktput(struct modemchannel *chan, const unsigned char *data, unsigned int len)
