@@ -3,8 +3,8 @@
 /*
  *      ptt.c  --  PTT signalling.
  *
- *      Copyright (C) 1999-2000
- *        Thomas Sailer (sailer@ife.ee.ethz.ch)
+ *      Copyright (C) 1999-2000, 2002
+ *        Thomas Sailer (t.sailer@alumni.ethz.ch)
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ int pttinit(struct pttio *state, const char *params[])
 	if (!ioctl(fd, TIOCMBIC, &y)) {
 		state->fd = fd;
 		state->mode = serport;
-	} else if (!ioctl(fd, PPRDATA, &x)) {
+	} else if (!ioctl(fd, PPCLAIM, 0) && !ioctl(fd, PPRDATA, &x)) {
 		state->fd = fd;
 		state->mode = parport;
 	} else {
@@ -103,14 +103,21 @@ int pttinit(struct pttio *state, const char *params[])
 void pttsetptt(struct pttio *state, int pttx)
 {
 	unsigned char reg;
-	unsigned char y = TIOCM_RTS;
 
 	if (!state || state->fd == -1)
 		return;
 	state->ptt = !!pttx;
-	if (state->mode == serport)
+	if (state->mode == serport) {
+#if 0
+		unsigned int y = TIOCM_RTS;
 		ioctl(state->fd, state->ptt ? TIOCMBIS : TIOCMBIC, &y);
-	else if (state->mode == parport) {
+#else
+		unsigned int y;
+		ioctl(state->fd, TIOCMGET, &y);
+		y |= TIOCM_RTS;
+		ioctl(state->fd, TIOCMSET, &y);
+#endif
+	} else if (state->mode == parport) {
 		reg = state->ptt | (state->dcd << 1);
 		ioctl(state->fd, PPWDATA, &reg);
 	}
@@ -119,14 +126,21 @@ void pttsetptt(struct pttio *state, int pttx)
 void pttsetdcd(struct pttio *state, int dcd)
 {
 	unsigned char reg;
-	unsigned char y = TIOCM_DTR;
 
 	if (!state || state->fd == -1)
 		return;
 	state->dcd = !!dcd;
-	if (state->mode == serport)
+	if (state->mode == serport) {
+#if 0
+		unsigned int y = TIOCM_DTR;
 		ioctl(state->fd, state->dcd ? TIOCMBIS : TIOCMBIC, &y);
-	else if (state->mode == parport) {
+#else
+		unsigned int y;
+		ioctl(state->fd, TIOCMGET, &y);
+		y |= TIOCM_DTR;
+		ioctl(state->fd, TIOCMSET, &y);
+#endif
+	} else if (state->mode == parport) {
 		reg = state->ptt | (state->dcd << 1);
 		ioctl(state->fd, PPWDATA, &reg);
 	}
